# eric7.Plugins.VcsPlugins.vcsMercurial.HgPhaseDialog

Module implementing a dialog to enter data for the Mercurial Phase operation.

### Global Attributes

None

### Classes

HgPhaseDialog | Class dimplementing a dialog to enter data for the Mercurial Phase operation.

### Functions

None

## HgPhaseDialog

Class dimplementing a dialog to enter data for the Mercurial Phase operation.

### Derived from

QDialog, Ui_HgPhaseDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgPhaseDialog | Constructor
__updateOk | Private slot to update the state of the OK button.
getData | Public method to retrieve the entered data.
on_phaseCombo_activated | Private slot to react upon changes of the phase.
on_revisionsEdit_textChanged | Private slot to react upon changes of revisions.

### Static Methods

None

#### HgPhaseDialog (Constructor)

HgPhaseDialog(parent=None)

Constructor

parent
  reference to the parent widget (QWidget)

#### HgPhaseDialog.__updateOk

__updateOk()

Private slot to update the state of the OK button.

#### HgPhaseDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple with list of revisions, phase and a flag indicating a forced operation (list of strings, string, boolean)

#### HgPhaseDialog.on_phaseCombo_activated

on_phaseCombo_activated(index)

Private slot to react upon changes of the phase.

index (int)
  index of the selected entry

#### HgPhaseDialog.on_revisionsEdit_textChanged

on_revisionsEdit_textChanged()

Private slot to react upon changes of revisions.

Up